<?php
namespace Controller;

use Exception\LoginException;
use Util\Environment;
use Util\InstanceProvider;
use Zeedhi\Framework\HTTP\Kernel;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Service\LoginService;
use Util\Utilities;
use Zeedhi\Framework\Session\Session;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Service\Traits\TResponse;

class Login {

    use TResponse;

    /** @var Kernel  */
    private $kernel;
    /** @var LoginService  */
    private $loginService;
    
    protected $environment;

    public function __construct(Environment $environment, Kernel $kernel, LoginService $loginService){
        $this->environment = $environment;
        $this->kernel = $kernel;
        $this->loginService = $loginService;
    }

    public function getLoggedUser(DTO\Request $request, DTO\Response $response){

        try{
            $parameters = $request->getParameters();
            $nrorg = $parameters["nrorg"];
            $nrorgPrincipal = $parameters["nrorgPrincipal"];
            $userAcl = $this->environment->getAclProfilesLogin();

            if($nrorg){
                $this->environment->setNrOrgClient($nrorg);
            }
            $this->environment->setNrOrgClientPrincipal($nrorgPrincipal);
            $loggedUser = $this->loginService->getLoggedUser($userAcl);
            $this->environment->setOrganizationId($loggedUser[Environment::ORG_ID]);
            $this->sendResponse($loggedUser, 200);
        } catch(\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function logout(Request $request, Response $response) {
        $httpRequest = $this->kernel->getHttpRequest();
        $token = $httpRequest->get('TOKEN');
        $this->loginService->destroySession($token);
        $response->addDataSet(new DataSet('logout', array(true)));
    }

    public function aclRules(Request $request, Response $response) {
        InstanceProvider::getAccessControlRule()->find($request,$response);

        $currentNrOrg = Utilities::getOrganizationIdForMongo();
        $organizationId = Utilities::getEnvironment()->getCurrentOrganizationId();
        $nrorgoper = Utilities::getEnvironment()->getNrorgoper();
        if($nrorgoper){
            $organizationId = $nrorgoper;
        }
        if($currentNrOrg != $organizationId){
            $rules = array(
                array(
                    "GROUP_ID" => null,
                    "NAME" => "access_profile",
                    "RULE" => "I",
                    "RULE_UNDEFINED" => "N",
                    "UNIQUE_ID" => "976714833894200501522"
                ),
                array(
                    "GROUP_ID" => null,
                    "NAME" => "operator",
                    "RULE" => "I",
                    "RULE_UNDEFINED" => "N",
                    "UNIQUE_ID" => "177177449685236710829"
                ),
                array(
                    "GROUP_ID" => null,
                    "NAME" => "acl",
                    "RULE" => "I",
                    "RULE_UNDEFINED" => "N",
                    "UNIQUE_ID" => "9088430362269543295713"
                ),
                array(
                    "GROUP_ID" => null,
                    "NAME" => "operator",
                    "RULE" => "I",
                    "RULE_UNDEFINED" => "N",
                    "UNIQUE_ID" => "9088430361400939329769"
                ),
                array(
                    "GROUP_ID" => null,
                    "NAME" => "accessProfile",
                    "RULE" => "I",
                    "RULE_UNDEFINED" => "N",
                    "UNIQUE_ID" => "9088430364218802137714"
                ),
                array(
                    "GROUP_ID" => null,
                    "NAME" => "myProfile",
                    "RULE" => "I",
                    "RULE_UNDEFINED" => "N",
                    "UNIQUE_ID" => "908843036876133788849"
                ),
                array(
                    "GROUP_ID" => null,
                    "NAME" => "my_profile",
                    "RULE" => "I",
                    "RULE_UNDEFINED" => "N",
                    "UNIQUE_ID" => "150184108825248751805"
                )
            );
            $response->addDataSet(new DataSet('zhu_access_control_rule_login', $rules));
        }
    }

    public function sendPasswordMail(Request $request, Response $response){
        $row = $request->getRow();
    }

    public function updateCustomerInSession(Request\Filter $request, Response $response) {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $customerCode = Utilities::getValueInFilterDataSourceByName($conditions, 'CDCLIENTE');
            Session::set('CDCLIENTE', $customerCode);
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(),$e->getCode()));
        }
    }
}
