<?php


namespace Service;

use Util\Environment;
use Util\Utilities;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\Remote\cURLRequest;
use Zeedhi\Framework\Session\Session;
use \Exception\LoginException;

class LoginService {
    /** @var Session */
    protected $environment;

    public function __construct(Environment $environment){
        $this->environment = $environment;
    }

    /**
     * @return array
     */
    public function getSessionUserData(){

        return array(
            Environment::USR_ID        => $this->environment->getUserId(),
            Environment::USR_NAME      => $this->environment->getUserName(),
            Environment::USR_EMAIL     => $this->environment->getUserEmail(),
            Environment::ORG_ID        => $this->environment->getOrganizationId(),
            Environment::ORG_NAME      => $this->environment->getOrganizationName(),
            Environment::ACL_PROFILE   => $this->environment->getAclProfiles(),
            Environment::URL           => $this->environment->getUserUrl()
        );
    }


    public function getNrorg(){
        $cdoperador = $this->environment->getCurrentUserId();
        $organization = $this->environment->getCurrentOrganizationId();
        $sql = <<<SQL
        SELECT NVL(OPR.NRORGOPER,ORG.NRORG) AS NRORGOPER,ORG.NMORGANIZACAO
        FROM OPERADOR OPR
        JOIN ORGANIZACAO ORG ON(OPR.NRORG = ORG.NRORG)
        WHERE CDOPERADOR = '$cdoperador'
SQL;

        $result = \Util\InstanceProvider::getEntityManager()->getConnection()->fetchAll($sql);
        if(!empty($result)){
            $organization = $result[0]['NRORGOPER'];
            $this->environment->setNrorgoper($result[0]['NRORGOPER']);
            $this->environment->setCurrentTradingName($result[0]['NMORGANIZACAO']);
        }else{
            $this->environment->setNrorgoper(null);
        }
        return $organization;
    }


    public function getMigration($organizationId){
        $filterCriteria = new FilterCriteria('connection', array(
                array(
                    "columnName" => "organizationId",
                    "value" => array(strval($organizationId), intval($organizationId)),
                    "operator" => "IN")
            )
        );
        $organizationConnectionParams = Utilities::getMongoManager()->findBy($filterCriteria)->getRows()[0];

        return empty($organizationConnectionParams["migration"])?'no':$organizationConnectionParams["migration"];
    }

    /**
     * @param $token
     * @return array
     * @throws LoginException
     */
    public function getLoggedUser($userAcl){
        try {
            $this->environment->setAclProfiles($userAcl);
            $migation = $this->getMigration($this->environment->getCurrentOrganizationId());
            $organization = $this->getNrorg();
            return array(
                Environment::USR_ID        => $this->environment->getCurrentUserId(),
                Environment::USR_NAME      => $this->environment->getCurrentUserName(),
                Environment::USR_EMAIL     => $this->environment->getCurrentEmail(),
                Environment::ORG_ID        => $organization,
                Environment::ACL_PROFILE   => $userAcl,
                Environment::ORG_NAME      => $this->environment->getCurrentTradingName(),
                Environment::MIGRATION     => $migation,
                Environment::CLIENT_NRORG     => Utilities::getOrganizationIdForMongo(),
            );

        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function cleanSession() {
        $this->environment->cleanSession();
    }

}
